automake-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

[Automake-commit] [SCM] GNU Automake branch, micro, updated. v1.15-7-gc4


From: Peter Rosin
Subject: [Automake-commit] [SCM] GNU Automake branch, micro, updated. v1.15-7-gc40e27e
Date: Tue, 24 Nov 2015 11:44:06 +0000

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "GNU Automake".

http://git.sv.gnu.org/gitweb/?p=automake.git;a=commitdiff;h=c40e27e1c2a60f58e72e65d73d808f782d55494a

The branch, micro has been updated
       via  c40e27e1c2a60f58e72e65d73d808f782d55494a (commit)
      from  1768e836d428082334a07f710b85073d2ab82969 (commit)

Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we list those
revisions in full, below.

- Log -----------------------------------------------------------------
-----------------------------------------------------------------------

Summary of changes:
 NEWS                           |   10 ++++++++++
 THANKS                         |    1 +
 lib/compile                    |    5 +++--
 t/ax/am-test-lib.sh            |   11 +++++++++++
 t/{compile4.sh => compile7.sh} |    8 ++++----
 t/list-of-tests.mk             |    1 +
 6 files changed, 30 insertions(+), 6 deletions(-)
 copy t/{compile4.sh => compile7.sh} (88%)

diff --git a/NEWS b/NEWS
index 5744d12..661bf80 100644
--- a/NEWS
+++ b/NEWS
@@ -62,6 +62,16 @@
 
 ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 
+New in 1.15.1:
+
+* Miscellaneous changes:
+
+  - Support the Windows version of the Intel C Compiler (icl) in the
+    'compile' script in the same way the (compatible) Microsoft C Compiler
+       is supported.
+
+~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
+
 New in 1.15:
 
 * Improvements and refactorings in the install-sh script:
diff --git a/THANKS b/THANKS
index b66f744..9b9faa1 100644
--- a/THANKS
+++ b/THANKS
@@ -199,6 +199,7 @@ John Pierce                     address@hidden
 John Ratliff                    address@hidden
 John R. Cary                    address@hidden
 John W. Coomes                  address@hidden
+Jonathan L Peyton               address@hidden
 Jonathan Nieder                 address@hidden
 Joseph S. Myers                 address@hidden
 Josh MacDonald                  address@hidden
diff --git a/lib/compile b/lib/compile
index 69fad9c..dc7a6e7 100755
--- a/lib/compile
+++ b/lib/compile
@@ -1,7 +1,7 @@
 #! /bin/sh
 # Wrapper for compilers which do not understand '-c -o'.
 
-scriptversion=2012-10-14.11; # UTC
+scriptversion=2015-11-24.11; # UTC
 
 # Copyright (C) 1999-2015 Free Software Foundation, Inc.
 # Written by Tom Tromey <address@hidden>.
@@ -255,7 +255,8 @@ EOF
     echo "compile $scriptversion"
     exit $?
     ;;
-  cl | *[/\\]cl | cl.exe | *[/\\]cl.exe )
+  cl | *[/\\]cl | cl.exe | *[/\\]cl.exe | \
+  icl | *[/\\]icl | icl.exe | *[/\\]icl.exe )
     func_cl_wrapper "$@"      # Doesn't return...
     ;;
 esac
diff --git a/t/ax/am-test-lib.sh b/t/ax/am-test-lib.sh
index 35541c3..529d93b 100644
--- a/t/ax/am-test-lib.sh
+++ b/t/ax/am-test-lib.sh
@@ -779,6 +779,17 @@ require_tool ()
       $CC -? </dev/null \
         || skip_all_ "Microsoft C compiler '$CC' not available"
       ;;
+    icl)
+      CC=icl
+      # Don't export CFLAGS, as that could have been initialized to only
+      # work with the C compiler detected at configure time.  If the user
+      # wants CFLAGS to also influence 'icl', he can still export CFLAGS
+      # in the environment "by hand" before calling the testsuite.
+      export CC CPPFLAGS
+      echo "$me: running $CC -?"
+      $CC -? >/dev/null \
+        || skip_all_ "Intel C compiler '$CC' not available"
+      ;;
     etags)
       # Exuberant Ctags will create a TAGS file even
       # when asked for --help or --version.  (Emacs's etags
diff --git a/t/list-of-tests.mk b/t/list-of-tests.mk
index 01c1a53..b4a6c22 100644
--- a/t/list-of-tests.mk
+++ b/t/list-of-tests.mk
@@ -273,6 +273,7 @@ t/compile3.sh \
 t/compile4.sh \
 t/compile5.sh \
 t/compile6.sh \
+t/compile7.sh \
 t/compile_f90_c_cxx.sh \
 t/compile_f_c_cxx.sh \
 t/cond-basic.sh \


hooks/post-receive
diff --git a/t/compile4.sh b/t/compile7.sh
similarity index 88%
copy from t/compile4.sh
copy to t/compile7.sh
index f2f223f..0dad8fb 100644
--- a/t/compile4.sh
+++ b/t/compile7.sh
@@ -14,10 +14,10 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 # Make sure 'compile' wraps the Microsoft C/C++ compiler (cl) correctly
 # with respect to absolute paths.
 
-required='cl'
+required='icl'
 . test-init.sh
 
 get_shell_script compile
@@ -67,14 +67,14 @@ $AUTOMAKE -a
 ./configure
 $MAKE
 
-./compile cl $CPPFLAGS $CFLAGS -c -o "$absmainobj" "$absmainc"
+./compile icl $CPPFLAGS $CFLAGS -c -o "$absmainobj" "$absmainc"
 
 # POSIX mandates that the compiler accepts a space between the -I,
 # -l and -L options and their respective arguments.  Traditionally,
 # this should work also without a space.  Try both usages.
 for sp in '' ' '; do
   rm -f main
-  ./compile cl $CFLAGS $LDFLAGS -L${sp}"$absfoodir" "$absmainobj" \
+  ./compile icl $CFLAGS $LDFLAGS -L${sp}"$absfoodir" "$absmainobj" \
                -o main -l${sp}foo
   ./main
 done
@@ -14,10 +14,10 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-# Make sure 'compile' wraps the Microsoft C/C++ compiler (cl) correctly
+# Make sure 'compile' wraps the Intel C/C++ compiler (icl) correctly
 # with respect to absolute paths.
 
-- 
GNU Automake



reply via email to

[Prev in Thread] Current Thread [Next in Thread]